Clojure only.

us.whitford.fulcro.rad.database-adapters.git.pathom-plugin

Pathom env middleware for the Git database adapter.

Injects git repo references into the Pathom env per-request. Version-neutral: works with both Pathom 2 and Pathom 3 (the env is a plain map in both).

Pathom env middleware for the Git database adapter.

Injects git repo references into the Pathom env per-request. Version-neutral:
works with both Pathom 2 and Pathom 3 (the env is a plain map in both).
raw docstring

wrap-envclj

(wrap-env repository-mapper)
(wrap-env base-wrapper repository-mapper)

Wrap the Pathom environment with git repository references.

Arguments:

  • repository-mapper: function (fn [env] {schema-name repo-map})

Returns a function that wraps the environment with repo data.

Wrap the Pathom environment with git repository references.

Arguments:
- repository-mapper: function (fn [env] {schema-name repo-map})

Returns a function that wraps the environment with repo data.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries