Delete form middleware for Git database adapter.
Removes EDN entity file and commits the deletion.
Delete form middleware for Git database adapter. Removes EDN entity file and commits the deletion.
(delete-entity! {:com.fulcrologic.rad.attributes/keys [key->attribute] :as env}
params)Delete an entity by removing its file (or directory) and committing. For directory entities (::gto/directory? true), recursively deletes the entity directory and all its contents. For scoped children (::gto/scoped? true), deletes the child file within the parent directory. Params must include parent identity.
Delete an entity by removing its file (or directory) and committing. For directory entities (::gto/directory? true), recursively deletes the entity directory and all its contents. For scoped children (::gto/scoped? true), deletes the child file within the parent directory. Params must include parent identity.
(wrap-git-delete)(wrap-git-delete handler)Form delete middleware for git-backed entities.
Form delete middleware for git-backed entities.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |