Pathom env middleware for the Git database adapter.
Injects git repo references into the Pathom env per-request. Version-neutral: works with both Pathom 2 and Pathom 3 (the env is a plain map in both).
Pathom env middleware for the Git database adapter. Injects git repo references into the Pathom env per-request. Version-neutral: works with both Pathom 2 and Pathom 3 (the env is a plain map in both).
(wrap-env repository-mapper)(wrap-env base-wrapper repository-mapper)Wrap the Pathom environment with git repository references.
Arguments:
Returns a function that wraps the environment with repo data.
Wrap the Pathom environment with git repository references.
Arguments:
- repository-mapper: function (fn [env] {schema-name repo-map})
Returns a function that wraps the environment with repo data.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |